# - Convenience include for using wxWidgets 
# Finds if wxWidgets is installed 
# and set the appropriate libs, incdirs, flags etc. 
# INCLUDE_DIRECTORIES, LINK_DIRECTORIES and ADD_DEFINITIONS
# are called.
#
# USAGE
# Include this file inside your CMakeLists.txt:
#   SET(WXWIDGETS_USE_GL 1) # optionally set this is you need wxgl
#   INCLUDE(${CMAKE_MODULE_PATH}/UsewxWidgsts.cmake)
#
# AUTHOR
# Jan Woetzel <jw -at- mip.informatik.uni-kiel.de>


# debug message and logging. 
# uncomment these for distribution
IF    (NOT LOGFILE )
  SET(LOGFILE "${PROJECT_BINARY_DIR}/CMakeOutput.log")
ENDIF (NOT LOGFILE )
MACRO(MSG _MSG)
#  FILE(APPEND ${LOGFILE} "${CMAKE_CURRENT_LIST_FILE}(${CMAKE_CURRENT_LIST_LINE}):   ${_MSG}\n")
#  MESSAGE(STATUS "${CMAKE_CURRENT_LIST_FILE}(${CMAKE_CURRENT_LIST_LINE}): ${_MSG}")
ENDMACRO(MSG)

#
# set wx libs we depend on. 
# "std" libs is only supporte dby linux
# emulate "std" behavior here.
#
IF   (WIN32)
  # useful std wx libs 
  # workaround until Find script supports std libs with wx msw  mono and multi build 
  SET(WXWIDGETS_LIBS_STD
    expat regex 
    jpeg png tiff zlib  
    # xml net adv media html odbc xrc
    )
  MSG("WXWIDGETS_LIBS_STD=${WXWIDGETS_LIBS_STD}")
  
  # use mono instead of multilib build?
  OPTION(WXWIDGETS_USE_MONOLITHIC "use monolithic WX USE_LIBS etting  for build?" OFF)
  #MARK_AS_ADVANCED(WXWIDGETS_USE_MONOLITHIC)
  MSG("WXWIDGETS_USE_MONOLITHIC=${WXWIDGETS_USE_MONOLITHIC}")
  
  IF   (WXWIDGETS_USE_MONOLITHIC)
    SET(WXWIDGETS_USE_LIBS ${WXWIDGETS_USE_LIBS}  
      mono 
      ${WXWIDGETS_LIBS_STD} )
    MSG("selected MONOLITHIC WX")
  ELSE (WXWIDGETS_USE_MONOLITHIC)
    SET(WXWIDGETS_USE_LIBS ${WXWIDGETS_USE_LIBS}  
      base core
      ${WXWIDGETS_LIBS_STD} )
    MSG("selected MULTILIB WX")
  ENDIF(WXWIDGETS_USE_MONOLITHIC)
ELSE (WIN32)
  # use wx std libs
  SET(WXWIDGETS_USE_LIBS ${WXWIDGETS_USE_LIBS} std)
ENDIF(WIN32)

# check WXWIDGETS and WXWINDOWS for backward compatibility 
#OPTION(WXWIDGETS_USE_GL "use wxgl lib with wxWidgets?" OFF)
IF   (WXWIDGETS_USE_GL OR WXWINDOWS_USE_GL)
  SET(WXWIDGETS_USE_LIBS ${WXWIDGETS_USE_LIBS} gl)
ENDIF(WXWIDGETS_USE_GL OR WXWINDOWS_USE_GL)


#
# start the find script with the above settings 
#
FIND_PACKAGE(wxWidgets REQUIRED)

#
# add results
#
MSG("WXWIDGETS_FOUND=${WXWIDGETS_FOUND}")
IF(   WXWIDGETS_FOUND)
  IF   (WXWIDGETS_INCLUDE_DIR)
    INCLUDE_DIRECTORIES( ${WXWIDGETS_INCLUDE_DIR} )
    MSG("WXWIDGETS_INCLUDE_DIR=${WXWIDGETS_INCLUDE_DIR}")
  ENDIF(WXWIDGETS_INCLUDE_DIR)

  IF   (WXWIDGETS_LINK_DIRECTORIES)
    LINK_DIRECTORIES(${WXWIDGETS_LINK_DIRECTORIES})
    MSG("WXWIDGETS_LINK_DIRECTORIES=${WXWIDGETS_LINK_DIRECTORIES}")
  ENDIF(WXWIDGETS_LINK_DIRECTORIES)

  IF   (WXWIDGETS_CXX_FLAGS)
    SET(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} ${WXWIDGETS_CXX_FLAGS}")
    MSG("WXWIDGETS_CXX_FLAGS=${WXWIDGETS_CXX_FLAGS}")
  ENDIF(WXWIDGETS_CXX_FLAGS)

  IF   (WXWIDGETS_DEFINITIONS)
    ADD_DEFINITIONS( ${WXWIDGETS_DEFINITIONS} )
    MSG("WXWIDGETS_DEFINITIONS=${WXWIDGETS_DEFINITIONS}")
  ENDIF(WXWIDGETS_DEFINITIONS)  

  # just for backward compatibility: add deps to all targets
  # library projects better use advanced FIND_PACKAGE(wxWidgets) directly.
  IF(WXWIDGETS_LIBRARIES)
    LINK_LIBRARIES(${WXWIDGETS_LIBRARIES})
    # BUG: str too long MSG("WXWIDGETS_LIBRARIES=${WXWIDGETS_LIBRARIES}")
    FILE(APPEND ${LOGFILE} "${CMAKE_CURRENT_LIST_FILE}(${CMAKE_CURRENT_LIST_LINE}):   ${WXWIDGETS_LIBRARIES}\n")    
  ENDIF(WXWIDGETS_LIBRARIES)


ELSE (WXWIDGETS_FOUND)
  MESSAGE("wxWidgest requested but not found.")
ENDIF(WXWIDGETS_FOUND) 
